/**
  ******************************************************************************
  * @file    HMC5883L.h
  * @author  Waveshare Team
  * @version V1.0
  * @date    29-August-2014
  * @brief   Header file for HMC5883L.c module.
  
  ******************************************************************************
  * @attention
  *
  * THE PRESENT FIRMWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS
  * WITH CODING INFORMATION REGARDING THEIR PRODUCTS IN ORDER FOR THEM TO SAVE
  * TIME. AS A RESULT, WAVESHARE SHALL NOT BE HELD LIABLE FOR ANY
  * DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING
  * FROM THE CONTENT OF SUCH FIRMWARE AND/OR THE USE MADE BY CUSTOMERS OF THE
  * CODING INFORMATION CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.
  *
  ******************************************************************************
  */



#ifndef __HMC5883L_H
#define __HMC5883L_H

#include "Public_StdTypes.h"

#define HMC5883L_DEVICE_ADDR       0x3C    //Device address
#define HMC5883L_CRA               0x00    //Configuration Register A
#define HMC5883L_DOR               0x06    //Typical Data Output Rate (Hz)
#define HMC5883L_MM                0x00    //Normal  Measurement Mode
#define HMC5883L_SAMPLE_AVERAGE    0x03    //Select number of samples averaged (1 to 8) per measurement output.    

#define HMC5883L_CRB               0x01    //Configuration Register B 
#define HMC5883L_GAIN              0x05    //Gain Configuration Bits.

#define HMC5883L_MR                0x02    //Mode Register
#define HMC5883L_CMM               0x00    //Continuous-Measurement Mode


#define HMC5883L_SR                0x09    //Status Register 

typedef struct
{
	uint8_t Index;
	int16_t AvgBuffer[8];
}HMC5883L_AvgTypeDef;

extern int16_t MagAngle[3];

extern void HMC5883L_Init(void);
extern void HMC5883L_DataOutRegister(int16_t *pData);
extern void HMC5883L_Compass(int16_t MagAngleX, int16_t MagAngleY, float *Angle);

#endif

/******************* (C) COPYRIGHT 2014 Waveshare *****END OF FILE*******************/


